@@ -17,11 +17,11 @@ def charMassivaAp(user,BASE,OGRDS,nameColumn1,charNum1,nameColumn2,charNum2,file
         return file
 # ---------------------------------------------------------------------------------------
     ''' Função criação de arquivos modelo.'''  
-    #modelo = pd.read_csv('C:/Users/{}/Google Drive/_jupyter/_massivo/_model-file/csv-modelo.csv'.format(user),delimiter = ';') # WIN
-    #modelo2 = pd.read_csv('C:/Users/{}/Google Drive/_jupyter/_massivo/_model-file/csv-modelo.csv'.format(user),delimiter = ';')
+    modelo = pd.read_csv('C:/Users/{}/Google Drive/_jupyter/_massivo/_model-file/csv-modelo.csv'.format(user),delimiter = ';') # WIN
+    modelo2 = pd.read_csv('C:/Users/{}/Google Drive/_jupyter/_massivo/_model-file/csv-modelo.csv'.format(user),delimiter = ';')
 
-    modelo = pd.read_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_model-file/csv-modelo.csv',delimiter = ';') # MAC
-    modelo2 = pd.read_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_model-file/csv-modelo.csv',delimiter = ';')
+    #modelo = pd.read_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_model-file/csv-modelo.csv',delimiter = ';') # MAC
+    #modelo2 = pd.read_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_model-file/csv-modelo.csv',delimiter = ';')
 
     OGRDS['ItmId'] = OGRDS['#BR LOC 0002 : PC ITEM'].str.slice(1,50) # OGRDS CLEANING  
     OGRDS['ItmId'] = OGRDS['ItmId'].astype(float) # CONVERSÃO DE COLUNAS to FLOAT
@@ -42,6 +42,7 @@ def charMassivaAp(user,BASE,OGRDS,nameColumn1,charNum1,nameColumn2,charNum2,file
     #contando
     contaAp = len(varErrorAp)
     contaPromo = len(varErrorPromo)
+    contaTotal = contaAp + contaPromo
 
     logErrorAp = varErrorAp.loc[varErrorAp['Item Code'].isnull()]
     logErrorPromo = varErrorPromo.loc[varErrorPromo['Item Code'].isnull()]
@@ -67,9 +68,9 @@ def charMassivaAp(user,BASE,OGRDS,nameColumn1,charNum1,nameColumn2,charNum2,file
     modelo2['CHAR_CODE'] = numPROMO
     modelo2['CHAR_DSCR'] = var90020[nameColumn2] 
     final = pd.concat([modelo, modelo2], axis=0, join='inner') # Concatenando modelos
-    #final.to_csv('C:/Users/{}/Google Drive/_jupyter/_massivo\_csv-file/{}.csv'.format(user,fileName),index=False) # WIN
-    final.to_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_csv-file/{}.csv'.format(fileName),index=False) # MAC
-    return print(f' > Processo concluído!  ALTERADO(s) AP. REGULAR: {contaAp} ALTERADO(s) PROMO: {contaPromo}\n> \033[0;31mNúmero total de registro(s) \033[m{len(final)}\n > \033[0;31mItens não Encontrados:\033[m \033[0;31mAp. Regular: \033[m {len(logErrorAp)}  \033[0;31mPromocao: \033[m {len(logErrorPromo)}')
+    final.to_csv('C:/Users/{}/Google Drive/_jupyter/_massivo\_csv-file/{}.csv'.format(user,fileName),index=False) # WIN
+    #final.to_csv('/Users/jeisosilva/Google Drive Nielsen/_jupyter/_massivo/_csv-file/{}.csv'.format(fileName),index=False) # MAC
+    return print(f' ALTERADO(s) AP. REGULAR: \033[0;31m{contaAp}\033[m ALTERADO(s) PROMO: \033[0;31m{contaPromo}\033[m  TOTAL de ALTERADOS:\033[0;31m {contaTotal}\033[m\n > Processo concluído!  \n > \033[0;31mNúmero total de registro(s) \033[m{len(final)}\n > Itens não Encontrados: \033[0;31mAp. Regular: \033[m {len(logErrorAp)}  \033[0;31mPromocao: \033[m {len(logErrorPromo)}')
 #---------------------------------------------------------------------------------------------------------------------------------------------
 # Validação de campo PROMOCAO  - versao 1.0 - last update: 25/02/2019
 def validaCampoPROMO(dataset,coluna,arg1,arg2,arg3):
